@@ -2,7 +2,7 @@ from django.conf import settings
 from django.utils.translation import gettext_lazy as _
 import os
 
-COOKIE_CONSENT_LOGO = getattr(settings, "COOKIE_CONSENT_LOGO", "cookie_consent/img/ga-logo.svg")
+COOKIE_CONSENT_LOGO = getattr(settings, "COOKIE_CONSENT_LOGO", "cookie_consent/img/ga-logo-cookie.svg")
 COOKIE_CONSENT_LOGO_URL = getattr(settings, "COOKIE_CONSENT_LOGO_URL", "https://goodadvice.it")
 COOKIE_CONSENT_TITLE = getattr(settings, "COOKIE_CONSENT_TITLE", _("Cookies"))
 COOKIE_CONSENT_DESCRIPTION = getattr(settings, "COOKIE_CONSENT_DESCRIPTION", _("This site uses cookies to improve your experience."))
