@@ -1,6 +1,11 @@
 document.addEventListener("DOMContentLoaded", function(e){
     const cookieModalWrapper = document.getElementById('cookie-consent-modal-wrapper');
 
+    if (!cookieModalWrapper) {
+        console.warn('Cookie consent modal wrapper not found.');
+        return;
+    }
+
     const tabs = {}
     let buttons = cookieModalWrapper.querySelectorAll('.ga-cookie-modal-btn');
     for (let i=0; i<buttons.length; i++) {
